@@ -22,7 +22,7 @@ class AsyncTestCase:
     def assertEqual(self, a, b):
         if a != b:
             raise ValueError(
-                f"{beeprint.pp(a, output=False, sort_keys=False, string_break_enable=False)}!=\n{beeprint.pp(b, output=False, sort_keys=False, string_break_enable=False)}")
+                f"\n{beeprint.pp(a, output=False, sort_keys=False, string_break_enable=False)}!=\n{beeprint.pp(b, output=False, sort_keys=False, string_break_enable=False)}")
 
     def assertTrue(self, a):
         self.assertEqual(True, a)
@@ -75,7 +75,8 @@ def run():
         [await task for task in subclass_test_tasks]
 
     loop.run_until_complete(main())
-    logger.info(f'Spent seconds: {loop.time() - start}, error count:{error_count}')
+    (logger.warning if not error_count else logger.error)(
+        f'Spent seconds: {loop.time() - start}, error count:{error_count}')
 
 
 if __name__ == '__main__':
